/** 3D数据加密解密 */
import CryptoJS from "crypto-js";

/** 部署时获取资源路径以及数据 */
export const getResource = (data: any, path: string, type: 'deploy' | 'toVue2' | 'toVue3' | 'toReact'|'deployAsZip') => {
  const _data = JSON.parse(
    JSON.stringify(parseData(data)).replace(
      /\?versionId=([^\"]+)/g,
      ""
    )
  );
  let resultData: any[] = [];
  if (type === "deploy") {
    const result = deploy(_data, "/view");
    resultData = [
      ...result.resources,
      { path: `/view/projects/${path}`, data: result.data },
    ];
  } else if (
    type === "toVue3" ||
    type === "toVue2" ||
    type === "toReact"
  ) {
    const storePath = {
      toVue3: "/vue3/public/view/",
      toVue2: "/vue2/public/view/",
      toReact: "/react/public/view/",
    }[type];
    const result = deploy(_data, storePath);
    resultData = [
      ...result.resources,
      {
        path: joinUrl(`${storePath}projects/${path}`),
        data: result.data,
      },
    ];
  } else if (type === 'deployAsZip') {
    const result = deployAsZip(_data);
    resultData = [
      ...result.resources,
      { path: `${path}`, data: result.data },
    ];
  }
  return resultData;
};

const parseData = (data: any) => {
  if (typeof data === "string") {
    data = data.startsWith("{") ? data : decrypto(data);
    return JSON.parse(data);
  }
  return data;
};

/** 加密，data为未加密的json数据 */
const crypto = (data: string) => {
  return c(data);
};

/** 解密，data为加密后的json数据 */
const decrypto = (data: string) => {
  return d(data);
};

function s16() {
  let chars = [
    "0",
    "1",
    "2",
    "3",
    "4",
    "5",
    "6",
    "7",
    "8",
    "9",
    "A",
    "B",
    "C",
    "D",
    "E",
    "F",
    "G",
    "H",
    "I",
    "J",
    "K",
    "L",
    "M",
    "N",
    "O",
    "P",
    "Q",
    "R",
    "S",
    "T",
    "U",
    "V",
    "W",
    "X",
    "Y",
    "Z",
    "a",
    "b",
    "c",
    "d",
    "e",
    "f",
    "g",
    "h",
    "i",
    "j",
    "k",
    "l",
    "m",
    "n",
    "o",
    "p",
    "q",
    "r",
    "s",
    "t",
    "u",
    "v",
    "w",
    "x",
    "y",
    "z",
  ];
  let strs = "";
  for (let i = 0; i < 16; i++) {
    let id = Math.ceil(Math.random() * 61);
    strs += chars[id];
  }
  return strs;
}

const a = (word: string, k: string, i: string) => {
  const srcs = CryptoJS.enc.Utf8.parse(word);
  const encrypted = CryptoJS.AES.encrypt(srcs, CryptoJS.enc.Utf8.parse(k), {
    iv: CryptoJS.enc.Utf8.parse(i),
    mode: CryptoJS.mode.CBC,
    padding: CryptoJS.pad.Pkcs7,
  });
  return encrypted.ciphertext.toString().toUpperCase();
};

const b = (word: string, k: string, i: string) => {
  const encryptedHexStr = CryptoJS.enc.Hex.parse(word);
  const srcs = CryptoJS.enc.Base64.stringify(encryptedHexStr);
  const decrypt = CryptoJS.AES.decrypt(srcs, CryptoJS.enc.Utf8.parse(k), {
    iv: CryptoJS.enc.Utf8.parse(i),
    mode: CryptoJS.mode.CBC,
    padding: CryptoJS.pad.Pkcs7,
  });
  const decryptedStr = decrypt.toString(CryptoJS.enc.Utf8);
  return decryptedStr.toString();
};

const c = (word: string): string => {
  const k = s16().toUpperCase();
  const i = s16().toUpperCase();
  const d = a(word, k, i);
  return k + d + i;
};

const d = (word: string): string => {
  const k = word.substring(0, 16);
  const i = word.substring(word.length - 16);
  return b(word.substring(16, word.length - 16), k, i);
};

const deploy = (data: any, storePath = "") => {
  const { scenes, resourceUrls } = data;
  Object.keys(resourceUrls).forEach((key) => {
    const url = resourceUrls[key];
    if (
      typeof url === "string" &&
      ["http:", "https:", "/"].some((host) => url.startsWith(host))
    ) {
      const index = url.lastIndexOf("/assets/");
      if (index !== -1) {
        // 从/assets开始截取
        resourceUrls[key] = url.substring(index + 1);
      }
    }
  });
  // 加载场景用到的所有资源
  const urlCacheMap = new Map<string, string>();
  // 使用相对路径
  const filePath = "projects/assets/files/";
  const transUrl = (url: string) => {
    if (urlCacheMap.has(url)) {
      return urlCacheMap.get(url)!;
    }
    if (
      typeof url === "string" &&
      ["http:", "https:", "/"].some((host) => url.startsWith(host))
    ) {
      const suffix = filesuffix(url, true);
      const fullpath = joinUrl(filePath, createId() + suffix);
      urlCacheMap.set(url, fullpath);
      return fullpath;
    }
    return url;
  };

  for (const sceneData of scenes) {
    if (!sceneData) {
      continue;
    }
    const {
      nodes = [],
      scene = {},
      glbMap = {},
      textures = {},
      materials = {},
      DOMDatas = [],
    } = sceneData;
    Object.keys(glbMap).forEach((glbId) => {
      const { url, name } = glbMap[glbId];
      const newUrl = transUrl(url + name);
      glbMap[glbId].url = filepath(newUrl);
      glbMap[glbId].name = filename(newUrl, true);
    });

    for (const node of [
      scene,
      ...nodes,
      ...DOMDatas,
      ...Object.keys(materials).map((id) => materials[id]),
      ...Object.keys(textures).map((id) => textures[id]),
    ]) {
      convertResourceAddress(node, transUrl);
    }
  }
  const _data = JSON.stringify(data);
  return {
    resources: [...urlCacheMap].map(([url, path]) => ({
      url,
      path: joinUrl(storePath, path),
    })),
    data: crypto(_data),
  };
};

const deployAsZip = (
  data: any,
  rootPath: string = ""
) => {
  delete data.resourceUrls;
  const filePath = joinUrl(rootPath, "/files/");
  const fileUrlMap: { [url: string]: string } = {};
  // 加载场景用到的所有资源
  const transUrl = (url: string) => {
    if (!url || fileUrlMap[url]) {
      return;
    }
    if (
      typeof url === "string" &&
      ["http:", "https:", "/", "projects/assets/"].some((host) =>
        url.startsWith(host)
      )
    ) {
      fileUrlMap[url] = createId();
    }
  };
  const { scenes = [] } = data;
  for (const sceneData of scenes) {
    if (!sceneData) {
      continue;
    }
    const {
      nodes = [],
      scene = {},
      glbMap = {},
      textures = {},
      materials = {},
      DOMDatas = [],
    } = sceneData;
    Object.keys(glbMap).forEach((glbId) => {
      const { url, name } = glbMap[glbId];
      transUrl(url + name);
    });
    for (const node of [
      scene,
      ...nodes,
      ...DOMDatas,
      ...Object.keys(materials).map((id) => materials[id]),
      ...Object.keys(textures).map((id) => textures[id]),
    ]) {
      convertResourceAddress(node, transUrl, false);
    }
  }
  return {
    resources: Object.keys(fileUrlMap).map((url) => ({
      url,
      path: joinUrl(filePath, fileUrlMap[url]),
    })),
    data: JSON.stringify({
      data: crypto(JSON.stringify(data)),
      map: fileUrlMap,
    }),
  };
};

const filesuffix = (str: string, withDecimalPoint = false) => {
  const paths = getUrlNoParam(str).split("/");
  const name = paths[paths.length - 1];
  const i = name.lastIndexOf(".");
  if (i === -1) {
    return "";
  }
  return name.substring(withDecimalPoint ? i : i + 1).toLocaleLowerCase();
};

const getUrlNoParam = (url: string) => {
  return url.split("?")[0];
};

const joinUrl = (...urls: string[]) => {
  if (urls.length < 2) {
    return urls[0] || "";
  }
  return urls
    .map((url, index) => {
      if (index === 0) {
        return url.replace(/\/$/, "");
      }
      if (index === urls.length - 1) {
        return url.replace(/^\//, "");
      }
      return url.replace(/^\//, "").replace(/\/$/, "");
    })
    .join("/");
};

const createId = (prefix?: string) => {
  return `${prefix || ""}${RandomGUID()}`;
};

const RandomGUID = () => {
  return "xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g, (c) => {
    const r = (Math.random() * 16) | 0,
      v = c === "x" ? r : (r & 0x3) | 0x8;
    return v.toString(16);
  });
};

const filepath = (str: string, trimDelimiter = false) => {
  const paths = str.split("/");
  paths[paths.length - 1] = "";
  if (trimDelimiter) {
    if (paths[0] === "") {
      paths.shift();
    }
    if (paths[paths.length - 1] === "") {
      paths.pop();
    }
  }
  return paths.join("/");
};

const filename = (str: string, withSuffix = false) => {
  const paths = getUrlNoParam(str).split("/");
  const name = paths[paths.length - 1];
  if (withSuffix) {
    return name;
  }
  const i = name.lastIndexOf(".");
  if (i === -1) {
    return name;
  }
  return name.substring(0, i);
};

const urlProps = [
  "url",
  "imageSource",
  "skyboxUrl",
  "hdrUrl",
  "colorGradingTexture",
  "source",
  "backgroundImage",
];
const convertResourceAddress = (
  data: any,
  transFn: (url: string) => any,
  reset = true
) => {
  for (const urlProp of urlProps) {
    if (urlProp in data === false) {
      continue;
    }
    const url = data[urlProp] || "";
    const newUrl = transFn(url);
    if (reset) {
      data[urlProp] = newUrl;
    }
  }
  if (data.contents) {
    data.contents.forEach((content: any) =>
      convertResourceAddress(content, transFn, reset)
    );
  }
  if (data.__initOption) {
    convertResourceAddress(data.__initOption, transFn, reset);
  }
  if (data.children) {
    data.children.forEach((child: any) =>
      convertResourceAddress(child, transFn, reset)
    );
  }
};
